Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/npm/cli.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorisaacs <i@izs.me>2014-09-11 22:05:06 +0400
committerisaacs <i@izs.me>2014-09-11 22:05:06 +0400
commitab8dd87b943262f5996744e8d4cc30cc9358b7d7 (patch)
tree3dba453d743052105249aab2e81761797c006815
parent6e6a5fb74af10fd345411df4e121e554e2e3f33e (diff)
s/ronn/marked-man/g
-rw-r--r--.gitignore2
-rw-r--r--Makefile16
-rw-r--r--package.json2
-rwxr-xr-xscripts/doc-build.sh24
4 files changed, 22 insertions, 22 deletions
diff --git a/.gitignore b/.gitignore
index 44a8b75c7..234afda9c 100644
--- a/.gitignore
+++ b/.gitignore
@@ -6,7 +6,7 @@ npm-debug.log
/test/packages/npm-test-depends-on-spark/which-spark.log
/test/packages/test-package/random-data.txt
/test/root
-/node_modules/ronn
+/node_modules/marked-man
/node_modules/tap
/node_modules/nock
/node_modules/.bin
diff --git a/Makefile b/Makefile
index 540e2da05..fe2d963bb 100644
--- a/Makefile
+++ b/Makefile
@@ -72,7 +72,7 @@ dev: install
link: uninstall
node cli.js link -f
-clean: markedclean ronnclean doc-clean uninstall
+clean: markedclean marked-manclean doc-clean uninstall
rm -rf npmrc
node cli.js cache clean
@@ -84,19 +84,19 @@ doc: $(mandocs) $(htmldocs)
markedclean:
rm -rf node_modules/marked node_modules/.bin/marked .building_marked
-ronnclean:
- rm -rf node_modules/ronn node_modules/.bin/ronn .building_ronn
+marked-manclean:
+ rm -rf node_modules/marked-man node_modules/.bin/marked-man .building_marked-man
docclean: doc-clean
doc-clean:
rm -rf \
.building_marked \
- .building_ronn \
+ .building_marked-man \
html/doc \
html/api \
man
-# use `npm install ronn` for this to work.
+# use `npm install marked-man` for this to work.
man/man1/npm-README.1: README.md scripts/doc-build.sh package.json
@[ -d man/man1 ] || mkdir -p man/man1
scripts/doc-build.sh $< $@
@@ -161,10 +161,10 @@ marked: node_modules/.bin/marked
node_modules/.bin/marked:
node cli.js install marked --no-global
-ronn: node_modules/.bin/ronn
+marked-man: node_modules/.bin/marked-man
-node_modules/.bin/ronn:
- node cli.js install ronn --no-global
+node_modules/.bin/marked-man:
+ node cli.js install marked-man --no-global
doc: man
diff --git a/package.json b/package.json
index ae3b32b0e..38fa19e24 100644
--- a/package.json
+++ b/package.json
@@ -150,11 +150,11 @@
],
"devDependencies": {
"marked": "~0.3.2",
+ "marked-man": "~0.1.3",
"nock": "~0.34.1",
"npm-registry-couchapp": "~2.5.3",
"npm-registry-mock": "~0.6.3",
"require-inject": "~1.0.0",
- "ronn": "~0.3.6",
"tap": "~0.4.12"
},
"engines": {
diff --git a/scripts/doc-build.sh b/scripts/doc-build.sh
index 9afab0782..3728259ac 100755
--- a/scripts/doc-build.sh
+++ b/scripts/doc-build.sh
@@ -6,26 +6,26 @@ fi
set -o errexit
set -o pipefail
-if ! [ -x node_modules/.bin/ronn ]; then
+if ! [ -x node_modules/.bin/marked-man ]; then
ps=0
- if [ -f .building_ronn ]; then
- pid=$(cat .building_ronn)
+ if [ -f .building_marked-man ]; then
+ pid=$(cat .building_marked-man)
ps=$(ps -p $pid | grep $pid | wc -l) || true
fi
- if [ -f .building_ronn ] && [ $ps != 0 ]; then
- while [ -f .building_ronn ]; do
+ if [ -f .building_marked-man ] && [ $ps != 0 ]; then
+ while [ -f .building_marked-man ]; do
sleep 1
done
else
- # a race to see which make process will be the one to install ronn
- echo $$ > .building_ronn
+ # a race to see which make process will be the one to install marked-man
+ echo $$ > .building_marked-man
sleep 1
- if [ $(cat .building_ronn) == $$ ]; then
- make node_modules/.bin/ronn
- rm .building_ronn
+ if [ $(cat .building_marked-man) == $$ ]; then
+ make node_modules/.bin/marked-man
+ rm .building_marked-man
else
- while [ -f .building_ronn ]; do
+ while [ -f .building_marked-man ]; do
sleep 1
done
fi
@@ -68,7 +68,7 @@ mkdir -p $(dirname $dest)
case $dest in
*.[1357])
- ./node_modules/.bin/ronn --roff $src \
+ ./node_modules/.bin/marked-man --roff $src \
| sed "s|@VERSION@|$version|g" \
| perl -pi -e 's/(npm\\-)?([a-zA-Z\\\.\-]*)\(1\)/npm help \2/g' \
| perl -pi -e 's/(npm\\-)?([a-zA-Z\\\.\-]*)\(([57])\)/npm help \3 \2/g' \